@@ -1,5 +1,6 @@
 package Acme::CPANAuthors::AnyEvent;
 
+use 5.005;
 use utf8;
 use strict;
 use warnings;
@@ -12,11 +13,11 @@ Acme::CPANAuthors::AnyEvent - We are CPAN Authors of AnyEvent!
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Acme::CPANAuthors::Register(
 	MLEHMANN   => 'Marc Lehmann', # Main AnyEvent author ;)
@@ -30,6 +31,7 @@ use Acme::CPANAuthors::Register(
 	MIYAGAWA   => 'Tatsuhiko Miyagawa',
 	MONS       => 'Mons Anderson',
 	SEKIMURA   => 'Masayoshi Sekimura',
+	TOKUHIROM  => 'Tokuhiro Matsuno',
 	TYPESTER   => 'Daisuke Murase',
 	VTI        => 'Viacheslav Tykhanovskyi',
 	YANNK      => 'Yann Kerherve',
@@ -62,7 +64,7 @@ And if you aren't a AnyEvent CPAN author listed here, please send us your ID/nam
 
 =head1 CONTAINED AUTHORS
 
-Now B<14> AnyEvent CPAN authors:
+Now B<15> AnyEvent CPAN authors:
 
     MLEHMANN   => 'Marc Lehmann', # Main AnyEvent author ;) 
 
@@ -76,11 +78,12 @@ Now B<14> AnyEvent CPAN authors:
     MIYAGAWA   => 'Tatsuhiko Miyagawa',
     MONS       => 'Mons Anderson',
     SEKIMURA   => 'Masayoshi Sekimura',
+    TOKUHIROM  => 'Tokuhiro Matsuno',
     TYPESTER   => 'Daisuke Murase',
     VTI        => 'Viacheslav Tykhanovskyi',
     YANNK      => 'Yann Kerherve',
 
-And we written B<37> distros
+And we've written B<39> distros
 
 =head1 SEE ALSO
 
